<!-- 自定义封装弹层 -->
<template>
  <el-dialog
    custom-class="super-dialog"
    :class="classStyle"
    v-on="$listeners"
    v-bind="$attrs"
    :visible.sync="dialogVisible"
    :show-close="false"
    close-on-click-modal
    :top="top"
  >
    <!-- 关闭图标 -->
    <i
      class="el-icon-close cloes-icon"
      @click="dialogVisible = false"
    />
    <!-- 自定义头部内容 -->
    <div class="super-dialog-title">
      <div class="title-left">
        <div
          class="title"
          ref="title"
          :title="title"
        >{{ title }}
        </div>
      </div>
      <div class="title-end">
        <slot name="title-end"></slot>
      </div>
    </div>
    <!-- 内容默认插槽 -->
    <div class="super-dialog-content">
      <slot></slot>
    </div>
    <!-- 尾部按钮插槽 -->
    <template v-slot:footer>
      <slot name="footer"></slot>
    </template>
  </el-dialog>
</template>

<script>
export default {
  name: 'SuperDialog',
  model: {
    prop: 'showDialog',
    event: 'changeDialog'
  },
  props: {
    showDialog: {
      default: false,
      type: Boolean
    },
    title: {
      default: '标题',
      type: String
    },
    top: {
      default: '20vh',
      type: String
    },
    classStyle: {
      default: '',
      type: String
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.showDialog
      },
      set(val) {
        this.$emit('changeDialog', val)
      }
    }
  }
}
</script>

<style lang="scss" scoped>
::v-deep .super-dialog {
  box-sizing: border-box;

  .super-dialog-title {
    width: 100%;
    height: 44px;
    display: flex;
    justify-content: space-between;
    background: url("~@/assets/img/publicLayout/header-bg.png") no-repeat 50% 50%, linear-gradient(180deg, #1150A0 0%, #4686D6 100%);
    background-size: 100% 100%;
    color: #fff;
    padding: 0 20px;
    box-sizing: border-box;
    user-select: none;

    > * {
      height: 100%;
    }

    .title-left {
      width: 92%;
      display: flex;

      .title {
        width: 100%;
        font-size: 18px;
        font-weight: bold;
        display: flex;
        align-items: center;
      }

    }

    .title-end {
      display: flex;
      align-items: center;
    }
  }

  .super-dialog-content {
    box-sizing: border-box;
    padding: 20px;
  }

  .el-dialog__header {
    width: 0;
    height: 0;
    padding: 0;
  }

  .el-dialog__body {
    padding: 0;
  }

  .el-dialog__footer {
    padding-top: 0;
  }

  .cloes-icon {
    position: absolute;
    top: 12px;
    right: 16px;
    font-size: 18px;
    color: #fff;
    cursor: pointer;
  }
}
</style>
